function [output1 output2 output3] = getDynamicModel(input)
%% Construct tables
%Split species
fbar=waitbar(0,"Getting dynamic model...");
s_reac = string(input);
%s_reac = s_reac(:,1);
t_reac = array2table(s_reac,'VariableNames',{'Reaction','kfwd','krev'});
% Expand reversible reaction in two
ir=contains(t_reac.Reaction, '=');
t_reacir=t_reac(:,1:2);
irRows={};
for i=find(ir)'
    t_reacir.Reaction(i)=replace(t_reac.Reaction(i),"=","->");
    aux=regexp(t_reac.Reaction(i),' (=) ','split');
    irRows=[irRows;{join([aux(2), "->", aux(1)]), t_reac.krev(i)}];
end
t_reacir=[t_reacir;irRows]
    
%extract complexes
Cm = regexp(t_reacir.Reaction,' (->) ','split');
% For each complex, extract species
sp = cellfun(@(x) regexp(x, ' \+ ', 'split'),Cm, 'UniformOutput', false);


%% Get number of reactives and products
num_r = 0;%reactives
num_p = 0;%products
for i=1:length(sp)
    if(size(sp{i}{1},2)>num_r)
        num_r = size(sp{i}{1},2);
    end
    
    if(size(sp{i}{2},2)>num_p)
        num_p = size(sp{i}{2},2);
    end
end


%%  Span hierarchical cell in a dynamic cell
spc=cell(length(sp),num_p + num_r);

%clear
for i=1:length(sp)
    for j=1:num_p + num_r
        spc(i,j) = cellstr('');
    end
end

%reactives
for i=1:length(sp)
    for j=1:size(sp{i}{1},2)
        spc(i,j) = cellstr(sp{i}{1}(j));
    end
end

%products
for i=1:length(sp)
    for j=1:size(sp{i}{2},2)
        spc(i,j+num_r) = cellstr(sp{i}{2}(j));
    end
end

waitbar(0.1,fbar);

% Create table with reaction information
spt=cell2table(spc);

% Convert to string array
display("SPA");
spa=table2array(spt(:,1:num_p + num_r))


% find species. Alphabetical order
[species,ia,ic]=unique(spa);
% indices of species in reactions. 1 is used for no component
isp=reshape(ic,size(spa));
% Clear null species
species=species(2:end);
ne=length(species);
isp=isp-1;


%% Set Mass-Action Kinetics
for i=1:size(spa,1)
    current_reaction = spa(i,:);    
    vaux = 1;
    for k=1:2
        if(current_reaction(k)=="")
            %skip
        else
            vaux = vaux * str2sym(current_reaction(k));
        end
    end

    vaux = str2sym(t_reacir.kfwd(i))*vaux;
    v(i) = vaux;    
end


%% State variables
st_index = 1;
for i=1:length(species)
    if species(i)=="0"
        %skip
    else
        st_vars(st_index) = str2sym(species(i));
        st_index = st_index + 1;
    end
end

waitbar(0.2,fbar);
%% Dynamic Model Equations

f = st_vars;%symbolic declaration of var f

%reactives
for i=1:length(st_vars)
    for j=1:size(spa,1)
        for k=1:num_r
            if (spa(j,k)==string(st_vars(i)))
                f(i) = f(i) - v(j);
            end
        end

%products        
        for k=num_r+1:num_r+num_p
            if (spa(j,k)==string(st_vars(i)))
                f(i) = f(i) + v(j);
            end
        end
    end
    
waitbar(0.2 + (i/length(st_vars))*0.8,fbar);
end                
    
f = f - st_vars;%clear initial declaration
f = transpose(f)
st_vars = transpose(st_vars);


waitbar(0.99,fbar);
delete(fbar);
%% Output

%transpose(v)
%spa
output1 = st_vars;
output2 = str2sym(t_reacir.kfwd);
output3 = f;
%f



end

