function [output1 output2] = getModelData(inputCSV)
%%%%
Y=readReact(inputCSV);

%extract complexes
%separacion por = o -> (reactivos y productos)
Cm = regexp(Y.Reaction,' (=|->) ','split');

% For each complex, extract species
%separacion por especies en cada complejo
sp = cellfun(@(x) regexp(x, ' \+ ', 'split'),Cm, 'UniformOutput', false);

% span hierarchical cell in a nx4 cell
spc=cell(length(sp),4);
spc(:,1)=cellfun(@(x) x{1}(1), sp, 'UniformOutput', false);
spc(:,2)=cellfun(@(x) x{1}(2), sp, 'UniformOutput', false,'ErrorHandler',@(x,y) string(''));
spc(:,3)=cellfun(@(x) x{2}(1), sp, 'UniformOutput', false);
spc(:,4)=cellfun(@(x) x{2}(2), sp, 'UniformOutput', false,'ErrorHandler',@(x,y) string(''));

% Create table with reaction information
spt=cell2table(spc, 'VariableNames',{'S1', 'S2', 'P1', 'P2'});
% Include column with reversible reactions
% TODO
spt.isRev = contains(Y.Reaction, '=');

% Convert to string array
spa=table2array(spt(:,1:4));


% find species. Alphabetical order
[species,ia,ic]=unique(spa);
% indices of species in reactions. 1 is used for no component
isp=reshape(ic,size(spa));
% Elimina especie nula
species=species(2:end);
isp=isp-1;

aux=[1 0 1 0;...
     1 0 0 1;...
     0 1 1 0;...
     0 1 0 1];

 conn=[];
 for i=1:length(isp)
     aux1=[(isp(i,1:2)*aux(:,1:2)')', (isp(i,3:4)*aux(:,3:4)')'];
     conn=[conn; aux1];
     if spt.isRev(i)
         conn=[conn;aux1(:,[2,1])];
     end
 end
 iconn=find(min(conn')>0);
 conn=unique(conn(iconn,:),'rows');
 
 %Generate species graph
 Ge=digraph(conn(:,1),conn(:,2),[],cellstr(species));
 % Visualize graph
 output1 = Ge;
 output2 = [Y.Reaction Y.kfwd Y.krev];
 output2 = cellstr(output2);
 %display("output2 de getModelData");
 %display(output2);
end
 